@@ -19,7 +19,7 @@ sub call {
 
     my $trace;
     local $SIG{__DIE__} = sub {
-        $trace = $StackTraceClass->new;
+        $trace = $StackTraceClass->new(indent => 1, message => $_[0]);
         die @_;
     };
 
@@ -27,7 +27,7 @@ sub call {
     my $res = try { $self->app->($env) } catch { $caught = $_ };
 
     if ($trace && ($caught || ($self->force && ref $res eq 'ARRAY' && $res->[0] == 500)) ) {
-        my $text = trace_as_string($trace);
+        my $text = $trace->as_string;
         my $html = $trace->as_html;
         $env->{'plack.stacktrace.text'} = $text;
         $env->{'plack.stacktrace.html'} = $html;
@@ -47,21 +47,6 @@ sub call {
     return $res;
 }
 
-sub trace_as_string {
-    my $trace = shift;
-
-    my $st = '';
-    my $first = 1;
-    foreach my $f ( $trace->frames() ) {
-        $st .= "\t" unless $first;
-        $st .= $f->as_string($first) . "\n";
-        $first = 0;
-    }
-
-    return $st;
-
-}
-
 sub utf8_safe {
     my $str = shift;
 
